/*
 *    Library2.java
 *    Copyright (C) 2002 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3;

import org.greenstone.gsdl3.core.*;
import org.greenstone.gsdl3.util.*;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.File;
import java.io.IOException;
/**
 * A program to take XML cgi-input from the command line and return html
 *
 * @author <a href="mailto:kjdon@cs.waikato.ac.nz">Katherine Don</a>
 * @version $Revision: 3503 $
 */

final public class Library2 {
 
    public static void main(String args[]) {

	if (args.length != 3) {
	    System.out.println("Usage: Library2 <gsdl3 home> <site name> <interface name>");
	    System.exit(1);
	}

	ConfigVars config_ = new ConfigVars();
	config_.gsdl3_home_ = args[0];
	config_.site_name_ = args[1];
	config_.interface_name_ = args[2];

	config_.createXML();
	
	// new message router - create it and pass a handle to recept.
	// the servlet wont use this directly
	MessageRouter message_router_ = new MessageRouter();
	
	message_router_.setSiteHome(GSFile.siteHome(config_.gsdl3_home_, 
						    config_.site_name_));
	message_router_.configure();
	// new receptionist
	Receptionist recept_ = new Receptionist();
	recept_.setConfigVars(config_);
	recept_.setMessageRouter(message_router_);
	recept_.configure();

	BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
	String query=null;
	String result=null;
	while (true) {
	    System.out.println("Please enter an XML representation of cgi params (all on one line), or 'exit' to quit");
	    try {
		query = br.readLine();
	    } catch (Exception e) {
		System.err.println("Library1 exception:"+e.getMessage());
	    }
	    if (query.startsWith("exit")) {
		System.exit(1);
	    }
	    
	    result = recept_.process(query);

	    System.out.println(result);


	}

    }    
}

    
